@@ -1,17 +1,39 @@
 use strict;
 use warnings;
 package Acme::ProgressBar;
-{
-  $Acme::ProgressBar::VERSION = '1.127';
-}
 # ABSTRACT: a simple progress bar for the patient
-
+$Acme::ProgressBar::VERSION = '1.128';
 use Time::HiRes ();
 
+#pod =head1 SYNOPSIS
+#pod
+#pod  use Acme::ProgressBar;
+#pod  progress { do_something_slow };
+#pod
+#pod =cut
 
 use base qw(Exporter);
 our @EXPORT = qw(progress); ## no critic Export
 
+#pod =head1 DESCRIPTION
+#pod
+#pod Acme::ProgressBar provides a simple solution designed to provide accurate
+#pod countdowns.  No progress bar object needs to be created, and all the
+#pod calculation of progress through total time required is handled by the module
+#pod itself.
+#pod
+#pod =func progress
+#pod
+#pod  progress { unlink $_ for <*> };
+#pod  progress { while (<>) { $ua->get($_) } };
+#pod  progress { sleep 5; }
+#pod
+#pod There is only one function exported by default, C<progress>.  This function
+#pod takes a coderef as its lone argument.  It will execute this code and display a
+#pod simple progress bar indicating the time required for ten iterations through the
+#pod code.
+#pod
+#pod =cut
 
 sub progress(&) { ## no critic Prototype
   my ($code) = @_;
@@ -51,6 +73,17 @@ sub _overprint {
   print $message, "\r";
 }
 
+#pod =head1 TODO
+#pod
+#pod =for :list
+#pod * allow other divisions of time (other than ten)
+#pod
+#pod =head1 SEE ALSO
+#pod
+#pod L<Term::ProgressBar>, L<Term::ProgressBar::Simple>,
+#pod L<Progress::Any::Output::TermProgressBarColor>, L<Smart::Comments>
+#pod
+#pod =cut
 
 "48102931829 minutes remaining";
 
@@ -58,13 +91,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Acme::ProgressBar - a simple progress bar for the patient
 
 =head1 VERSION
 
-version 1.127
+version 1.128
 
 =head1 SYNOPSIS
 
@@ -101,10 +136,31 @@ allow other divisions of time (other than ten)
 
 =back
 
+=head1 SEE ALSO
+
+L<Term::ProgressBar>, L<Term::ProgressBar::Simple>,
+L<Progress::Any::Output::TermProgressBarColor>, L<Smart::Comments>
+
 =head1 AUTHOR
 
 Ricardo Signes <rjbs@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Ricardo SIGNES Sean Zellmer
+
+=over 4
+
+=item *
+
+Ricardo SIGNES <rjbs@codesimply.com>
+
+=item *
+
+Sean Zellmer <sean@lejeunerenard.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2010 by Ricardo Signes.
